@@ -1,6 +1,6 @@
 /* about.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011-2022 Ralf Hoffmann.
+ * Copyright (C) 2011-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -92,7 +92,7 @@ void About::about()
     ac1_texts->setMaxSpace( 5 );
     ac1_texts->setBorderWidth( 5 );
 
-    std::string str1 = AGUIXUtils::formatStringToString( "Worker %d.%d.%d%s|Copyright (C) 1998 - 2022 Ralf Hoffmann||Active options:",
+    std::string str1 = AGUIXUtils::formatStringToString( "Worker %d.%d.%d%s|Copyright (C) 1998 - 2023 Ralf Hoffmann||Active options:",
                                                          WORKER_MAJOR, WORKER_MINOR, WORKER_PATCH, WORKER_COMMENT );
     win->addMultiLineText( str1, *ac1_texts, 0, 0, NULL, NULL );
 
@@ -182,27 +182,19 @@ void About::about()
 #endif
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 
+#ifdef HAVE_HAL_DBUS
     /* HAL */
     row = option_lv->addRow();
     option_lv->setText( row, 0, "HAL support:" );
-#ifdef HAVE_HAL_DBUS
     option_lv->setText( row, 1, "yes" );
-#else
-    option_lv->setText( row, 1, "no" );
-#endif
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
-
+#elif defined(HAVE_DBUS)
     /* udisks */
     row = option_lv->addRow();
     option_lv->setText( row, 0, "UDisks support:" );
-#ifdef HAVE_DBUS
     option_lv->setText( row, 1, "yes" );
-#else
-    option_lv->setText( row, 1, "no" );
-#endif
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 
-#ifdef HAVE_DBUS
     row = option_lv->addRow();
     option_lv->setText( row, 0, "  UDisks available:" );
     if ( m_worker.getVolumeManager().getUDisksAvailable() == true ) {
@@ -213,6 +205,16 @@ void About::about()
         option_lv->setText( row, 1, "no" );
     }
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
+#else
+    row = option_lv->addRow();
+    option_lv->setText( row, 0, "HAL support:" );
+    option_lv->setText( row, 1, "no" );
+    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
+
+    row = option_lv->addRow();
+    option_lv->setText( row, 0, "UDisks support:" );
+    option_lv->setText( row, 1, "no" );
+    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 #endif
 
     /* EXE_STRING_LEN */
