@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2022 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -182,7 +182,7 @@ public:
   AGUIXFont *getFont( const char* );
   int setFont( const char* );
   void ExposeHandler(Message*);
-  AWindow *findAWindow(Window);
+  AWindow *findAWindow(Window, bool top_level);
   char *getNameOfKey(KeySym,unsigned int) const;
   Window getGroupWin() const;
   int queryPointer(Window win,int *x,int *y);
@@ -192,14 +192,14 @@ public:
   void unsetCursor(Window win);
 
   enum {WAIT_CURSOR=0,SCROLLH_CURSOR,SCROLLV_CURSOR,MAXCURSORS};
-  int startCut(GUIElement *elem,const char *buffer);
-  void cancelCut();
-  int startPaste(GUIElement *elem);
-  bool amiOwner() const;
-  const char *getCutBuffer() const;
-    void requestCut( Window win, bool fallback = false );
-    bool rerequestCut();
-  void cancelCutPaste(GUIElement *elem);
+  int startCut(GUIElement *elem,const char *buffer, bool use_clipboard);
+  void cancelCut(bool use_clipboard);
+  int startPaste(GUIElement *elem, bool use_clipboard);
+  bool amiOwner(bool use_clipboard) const;
+  std::string getCutBuffer(bool use_clipboard) const;
+  void requestCut( Window win, bool fallback, bool use_clipboard );
+  void rerequestCut();
+  void cancelCutPaste(GUIElement *elem, bool use_clipboard);
   bool isDoubleClick(struct timeval *t1,struct timeval *t2) const;
   bool isDoubleClick( Time t1, Time t2 ) const;
 
@@ -289,7 +289,8 @@ public:
                    XDNDPROXY,
                    XDNDAWARE,
                    CARDINAL_ATOM,
-                   NET_WM_ICON_ATOM
+                   NET_WM_ICON_ATOM,
+                   CLIPBOARD
     } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
@@ -305,14 +306,21 @@ public:
   bool getLastTypedWindowEvent( Window win, int type, XEvent *return_event );
   int addDefaultColors();
 
-    AWindow *getFocusedAWindow();
+    AWindow *getFocusedAWindow( bool top_level/* = false*/ );
 
     void registerBGHandler( AWindow *window, const RefCount< BackgroundMessageHandler > &handler );
     void unregisterBGHandler( AWindow *window );
     void executeBGHandlers( AGMessage &msg );
     void destroyBGHandlers();
 
-    void copyToClipboard( const std::string &s );
+    enum target_clipboard_buffer {
+        PRIMARY_BUFFER,
+        CLIPBOARD_BUFFER,
+        BOTH_BUFFERS
+    };
+
+    void copyToClipboard( const std::string &s, enum target_clipboard_buffer target );
+    void copyPrimaryToClipboard();
 
     /**
      * return the location and dimension of the largest (xinerama) screen
@@ -416,7 +424,8 @@ private:
       XA_TEXT_URI_LIST,
       XA_TEXT_PLAIN,
       XA_NET_WM_ICON,
-      XA_CARDINAL_ATOM;
+      XA_CARDINAL_ATOM,
+      XA_CLIPBOARD;
 
   int m_argc;
   char **m_argv;
@@ -469,7 +478,6 @@ private:
   void updateSystemColors( int changed_user_color );
 
   Cursor cursors[MAXCURSORS];
-  GUIElement *cutstart,*pastestart;
 
   unsigned int rootWindowWidth, rootWindowHeight;
   Pixmap backpm;
@@ -534,11 +542,19 @@ private:
     std::list< RefCount< BackgroundMessageHandler > > m_bg_handler_cleanup_list;
     std::list< AWindow *> m_bg_handler_erase_handler;
 
-    std::string clipboard_string;
+    class copy_and_paste_state {
+    public:
+        std::string buffer_string;
 
-    Atom m_last_selection_request_atom;
-    Window m_last_selection_request_window;
+        Atom last_selection_request_atom = None;
+        Window last_selection_request_window = None;
 
+        GUIElement *cutstart = NULL, *pastestart = NULL;
+    };
+
+    copy_and_paste_state m_primary_buffer_state;
+    copy_and_paste_state m_clipboard_state;
+    
     bool m_apply_window_dialog_type;
 
     bool m_override_xim;
