@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -997,23 +997,58 @@ void AWindow::removeFromContainer( Widget *twid )
   }
 }
 
-void AWindow::contMaximize( bool applyMinSize, bool applyMaxSize )
+void AWindow::contMaximize( bool applyMinSize, bool applyMaxSize, bool grow_only )
 {
-  int tw, th;
+    int tw, th;
+
+    if ( container == NULL ) {
+        return;
+    }
 
-  if ( container != NULL ) {
     // to maximize the window get the min width/height for
     // the container by resizing to 0,0 and finally add position
+
+    int ow = container->getWidth();
+    int oh = container->getHeight();
+      
     container->resize( 0, 0 );
+
+    int minw = container->getWidth();
+    int minh = container->getHeight();
+
+    if ( ! grow_only ) {
+        tw = minw;
+        th = minh;
+    } else {
+        bool resize_again = false;
+
+        if ( minw >= ow ) {
+            tw = minw;
+        } else {
+            tw = ow;
+            resize_again = true;
+        }
+        if ( minh >= oh ) {
+            th = minh;
+        } else {
+            resize_again = true;
+            th = oh;
+        }
+
+        if ( resize_again ) {
+            container->resize( tw, th );
+        }
+    }
+
     container->rearrange();
-    tw = container->getWidth();
-    th = container->getHeight();
+
     tw += container->getX();
+    minw += container->getX();
     th += container->getY();
-    if ( applyMinSize == true ) setMinSize( tw, th );
-    if ( applyMaxSize == true ) setMaxSize( tw, th );
+    minh += container->getY();
+    if ( applyMinSize == true ) setMinSize( minw, minh );
+    if ( applyMaxSize == true ) setMaxSize( minw, minh );
     resize( tw, th );
-  }
 }
 
 void AWindow::doCreateStuff()
