@@ -29,7 +29,7 @@ void CallBack::run_plain( Widget *elem )
 {
 }
 
-void CallBack::run( Widget *elem, AGMessage &msg )
+void CallBack::run( Widget *elem, const AGMessage &msg )
 {
   run_plain( elem );
 }
