@@ -516,6 +516,6 @@ void ChooseButton::prepareBG( bool force )
   if ( isCreated() == false ) return;
   if ( win == 0 ) return;
 
-  _aguix->SetWindowBG( win, _parent->getBG() );
+  _aguix->SetWindowBG( win, _aguix->getFaces().getAGUIXColor( "button-bg" ) );
   _aguix->SetWindowBG( lwin, _parent->getBG() );
 }
