@@ -63,8 +63,8 @@ PopUpMenu::PopUpMenu( AGUIX *parent,
         e.bg = it1->bg;
         e.highlight_on_show = it1->highlight_on_show;
 
-        if ( it1->type == SUBMENU && it1->submenu != NULL ) {
-            e.submenu = new PopUpMenu( parent, *(it1->submenu), getGroupID() );
+        if ( it1->type == SUBMENU ) {
+            e.submenu = new PopUpMenu( parent, it1->submenu, getGroupID() );
             e.submenu->setParentMenu( this );
         }
         m_entries.push_back( e );
@@ -439,7 +439,17 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
 
                     setHighlightEntry( highlighted_entry, -1 );
                 } else if ( msg->key == XK_Return ) {
-                    activateEntry( m_highlighted_entry );
+                    if ( m_highlighted_entry >= 0 &&
+                         (size_t)m_highlighted_entry <= m_entries.size() ) {
+                        if ( m_entries[ m_highlighted_entry ].type == SUBMENU ) {
+                            showEntry( m_highlighted_entry );
+                            setKeyboardFocus( false );
+                            m_entries[ m_highlighted_entry ].submenu->setKeyboardFocus( true );
+                            m_entries[ m_highlighted_entry ].submenu->highlightOnShowEntry( 0 );
+                        } else {
+                            activateEntry( m_highlighted_entry );
+                        }
+                    }
                 } else if ( msg->key == XK_Right ) {
                     int ty = 0;
                     for ( std::vector<InternPopUpEntry>::iterator it1 = m_entries.begin();
@@ -584,7 +594,7 @@ PopUpMenu::InternPopUpEntry::~InternPopUpEntry()
 PopUpMenu::PopUpEntry::PopUpEntry() : name( "" ),
                                       type( NORMAL ),
                                       id( -1 ),
-                                      submenu( NULL ),
+                                      submenu(),
                                       fg( -1 ),
                                       bg( -1 ),
                                       highlight_on_show( false )
