@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,8 +30,9 @@ const char *StringGadget::type="StringGadget";
 
 StringGadget::~StringGadget()
 {
-  _aguix->cancelCutPaste( this );
-  destroy();
+    _aguix->cancelCutPaste( this, false );
+    _aguix->cancelCutPaste( this, true );
+    destroy();
 }
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,const char *ttext,int tdata):GUIElement(taguix)
@@ -55,6 +56,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
   strongkeycapture=true;
   wantpaste=false;
   pasterequest=0;
+  paste_from_clipboard = false;
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
@@ -83,6 +85,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
   strongkeycapture=true;
   wantpaste=false;
   pasterequest=0;
+  paste_from_clipboard = false;
   setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
@@ -531,7 +534,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                             if ( strongkeycapture == true ) returnvalue = true;
 
                             if ( ! m_read_only ) {
-                                applySelection();
+                                applySelection( true );
                                 removeSelection();
                             }
 
@@ -539,12 +542,15 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                         } else if ( msg->key == XK_c && keystate == ControlMask ) {
                             if ( strongkeycapture == true ) returnvalue = true;
 
-                            applySelection();
+                            applySelection( true );
                         } else if ( msg->key == XK_v && keystate == ControlMask ) {
                             if ( strongkeycapture == true ) returnvalue = true;
 
                             if ( ! m_read_only ) {
-                                insertSelection();
+                                if ( content.getSelStart() != content.getSelEnd() ) {
+                                    removeSelection();
+                                }
+                                insertSelection( true );
                             }
 
                             textRedraw();
@@ -796,7 +802,7 @@ void StringGadget::deactivate()
   redraw();
 }
 
-void StringGadget::applySelection()
+void StringGadget::applySelection( bool both_buffers )
 {
   int x1,x2;
   char *buffer;
@@ -815,7 +821,10 @@ void StringGadget::applySelection()
       
       buffer = dupstring( content.getText() + x1 );
       buffer[x2 - x1] = 0;
-      _aguix->startCut( this, buffer );
+      _aguix->startCut( this, buffer, false );
+      if ( both_buffers ) {
+          _aguix->startCut( this, buffer, true );
+      }
       _freesafe( buffer );
     }
   }
@@ -835,19 +844,24 @@ void StringGadget::removeSelection()
   if ( content.getCursorPos() < content.getXOffset() ) content.setXOffset( content.getCursorPos() );
 }
 
-void StringGadget::insertSelection()
+void StringGadget::insertSelection( bool from_clipboard )
 {
-  if ( isCreated() == false ) return;
+    if ( isCreated() == false ) return;
 
-  if ( _aguix->amiOwner() == true ) {
-    std::string s2 = AGUIXUtils::remove_char( _aguix->getCutBuffer(), '\n' );
-    content.insertAtCursor( s2.c_str() );
-  } else {
-    _aguix->requestCut(getWindow());
-    _aguix->startPaste(this);
-    wantpaste=true;
-    pasterequest=time(NULL);
-  }
+    if ( _aguix->amiOwner( from_clipboard ) == true ) {
+        std::string s2 = AGUIXUtils::remove_char( _aguix->getCutBuffer( from_clipboard ), '\n' );
+        content.insertAtCursor( s2.c_str() );
+
+        if ( from_clipboard ) {
+            setCursor( content.getCursorPos() + s2.length() );
+        }
+    } else {
+        _aguix->requestCut( getWindow(), false, from_clipboard );
+        _aguix->startPaste( this, from_clipboard );
+        wantpaste = true;
+        pasterequest = time( NULL );
+        paste_from_clipboard = from_clipboard;
+    }
 }
 
 int StringGadget::setFont( const char *fontname )
@@ -958,6 +972,10 @@ void StringGadget::paste(unsigned char*buf)
       std::string s2 = AGUIXUtils::remove_char( (const char *)buf, '\n' );
       content.insertAtCursor( s2.c_str() );
       
+      if ( paste_from_clipboard ) {
+          setCursor( content.getCursorPos() + s2.length() );
+      }
+
       redraw();
     }
   }
