@@ -1,6 +1,6 @@
 /* stringgadget.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -118,12 +118,13 @@ private:
   
   void updateWin();
   void textRedraw();
-  void applySelection();
+  void applySelection( bool both_buffers = false );
   void removeSelection();
-  void insertSelection();
+  void insertSelection( bool from_clipboard = false );
 
   bool wantpaste;
   time_t pasterequest;
+  bool paste_from_clipboard;
   bool passwordMode;
   void lostFocus();
   void gotFocus();
