@@ -1,6 +1,6 @@
 /* text.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,8 +30,9 @@
 
 class Text:public GUIElement {
 public:
-  Text(class AGUIX *aguix,int x,int y,const char *text,int color);
   Text( class AGUIX *aguix, int x, int y, const char *text, int fg, int bg );
+  Text( class AGUIX *aguix, int x, int y, const char *text );
+
   virtual ~Text();
   Text( const Text &other );
   Text &operator=( const Text &other );
