@@ -1,6 +1,6 @@
 /* textstorage.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2020 Ralf Hoffmann.
+ * Copyright (C) 2005-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -325,6 +325,13 @@ AWidth &TextStorageString::getAWidth()
   return *m_lencalc;
 }
 
+void TextStorageString::setAWidth( const RefCount<AWidth> &lencalc )
+{
+    m_lencalc = lencalc;
+
+    initBuffer( m_current_line_limit );
+}
+
 int TextStorageString::findLineNr( std::pair<int,int> real_line ) const
 {
   int s = (int)_real_lines.size();
