@@ -1,6 +1,6 @@
 /* textstorage.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2020 Ralf Hoffmann.
+ * Copyright (C) 2005-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -43,6 +43,7 @@ class TextStorage
   virtual std::pair<int,int> getRealLinePair( int line_nr ) const = 0;
   virtual int findLineNr( std::pair<int,int> real_line ) const = 0;
   virtual AWidth &getAWidth() = 0;
+  virtual void setAWidth( const RefCount<AWidth> &lencalc ) = 0;
 
   virtual int getNrOfUnwrappedLines() const = 0;
   virtual int getUnwrappedLine( int line_nr,
@@ -91,6 +92,7 @@ class TextStorageString : public TextStorage
   std::pair<int,int> getRealLinePair( int line_nr ) const;
   int findLineNr( std::pair<int,int> real_line ) const;
   AWidth &getAWidth();
+  void setAWidth( const RefCount<AWidth> &lencalc ) override;
 
   int getNrOfUnwrappedLines() const;
   int getUnwrappedLine( int line_nr,
