@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2019 Ralf Hoffmann.
+ * Copyright (C) 2005-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -182,6 +182,11 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
   
   if ( isCreated() == false ) return false;
   
+  if ( msg->lockElement == this &&
+       m_selection_scroll_active ) {
+      msg->ack = true;
+  }
+
   if ( msg->type == Expose &&
        msg->window == win ) {
       drawBuffer( msg->x, msg->y, msg->width, msg->height );
@@ -204,31 +209,7 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
 
       _aguix->queryPointer( win, &mx, &my );
 
-      std::pair< int, int > cur = getTextPosForMousePos( mx, my );
-
-      if ( cur != m_button_press_unwrapped_line_pos ) {
-          int cur_sel = - 1, cur_off = -1;
-
-          getSelectionEnd( cur_sel, cur_off );
-
-          if ( cur_sel != cur.first || cur_off != cur.second ) {
-              if ( m_button_press_unwrapped_line_pos.first < cur.first ||
-                   ( m_button_press_unwrapped_line_pos.first == cur.first &&
-                     m_button_press_unwrapped_line_pos.second < cur.second ) ) {
-                  setSelectionStart( m_button_press_unwrapped_line_pos.first,
-                                     m_button_press_unwrapped_line_pos.second );
-                  setSelectionEnd( cur.first,
-                                   cur.second );
-              } else {
-                  setSelectionStart( cur.first,
-                                     cur.second );
-                  setSelectionEnd( m_button_press_unwrapped_line_pos.first,
-                                   m_button_press_unwrapped_line_pos.second );
-              }
-
-              redraw();
-          }
-      }
+      updateSelection( mx, my );
   } else if ( ( msg->type == ButtonPress ) && ( msg->window == win ) ) {
     if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
       gettimeofday( &t2, NULL );
@@ -265,11 +246,23 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
       redraw();
 
       m_button_press_unwrapped_line_pos = getTextPosForMousePos( msg->mousex, msg->mousey );
+
+      m_selection_scroll_active = true;
+      _aguix->Flush();
+      _aguix->msgLock( this );
+      _aguix->enableTimer();
     }
   } else if ( msg->type == ButtonRelease && msg->window == win ) {
       if ( msg->button == Button1 ) {
           copySelectionToClipboard();
 
+          if ( m_selection_scroll_active ) {
+              _aguix->Flush();
+              _aguix->disableTimer();
+              _aguix->msgUnlock( this );
+              m_selection_scroll_active = false;
+          }
+
           if ( _aguix->isDoubleClick( msg->time, m_last_mouse_time ) ) {
               int mx, my;
 
@@ -282,6 +275,37 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
               m_last_mouse_time = msg->time;
           }
       }
+  } else if ( msg->type == ClientMessage ) {
+      if ( msg->specialType == Message::TIMEREVENT &&
+           m_selection_scroll_active ) {
+          int mx, my;
+          const int hscroll_delta = getHScrollStep();
+          int textarea_x, textarea_y, textarea_w, textarea_h;
+
+          getTextArea( textarea_x,
+                       textarea_y,
+                       textarea_w,
+                       textarea_h );
+
+          _aguix->queryPointer( win, &mx, &my );
+
+          int xdelta = 0, ydelta = 0;
+
+          if ( mx < textarea_x ) {
+              xdelta = -hscroll_delta;
+          } else if ( mx > textarea_x + textarea_w ) {
+              xdelta = hscroll_delta;
+          }
+          if ( my < textarea_y ) {
+              ydelta = -1;
+          } else if ( my > textarea_y + textarea_h ) {
+              ydelta = 1;
+          }
+
+          if ( scrollView( xdelta, ydelta ) != 0 ) {
+              updateSelection( mx, my );
+          }
+      }
   }
 
   return AWindow::handleMessage( E, msg );
@@ -542,11 +566,25 @@ void TextView::drawLines( int start_x, int start_y, int width, int lines )
                     if ( selection_len > 0 ) {
                         std::string s2( s1, hidden_length, selection_len );
                         int selection_width = ts.getAWidth().getWidth( s2.c_str() );
+                        int max_line_width;
+                        int rectangle_x = start_x - hbar->getOffset() + hidden_width;
+
+                        int rectangle_hidden = 0; // pixels left of start_x that are clipped for the font, but must be
+                                                  // removed from drawn rectangle
+                        if ( rectangle_x < start_x ) {
+                            rectangle_hidden = start_x - rectangle_x;
+                        }
+
+                        if ( linePairEQ( cur_line, actual_sel_end.first ) == true ) {
+                            max_line_width = a_min( selection_width, overscan_width );
+                        } else {
+                            max_line_width = overscan_width;
+                        }
                         
                         _aguix->setFG( _colors.getSelectionBG() );
                         _aguix->FillRectangle( dc.getDrawable(),
-                                               start_x - hbar->getOffset() + hidden_width, i * elementHeight + start_y,
-                                               ( linePairEQ( cur_line, actual_sel_end.first ) == true ) ? selection_width : overscan_width,
+                                               rectangle_x + rectangle_hidden, i * elementHeight + start_y,
+                                               max_line_width - rectangle_hidden,
                                                elementHeight );
                         
                         _aguix->DrawText( dc, font, s2.c_str(),
@@ -1163,6 +1201,12 @@ bool TextView::handleKeyMessage( KeySym key,
             copySelectionToClipboard();
             redraw();
             break;
+        case XK_c:
+            if ( KEYSTATEMASK( keystate ) == ControlMask ) {
+                copySelectionToClipboard();
+                _aguix->copyPrimaryToClipboard();
+            }
+            break;
         default:
             break;
     }
@@ -1300,7 +1344,7 @@ void TextView::copySelectionToClipboard()
             s += temp_line_str;
         }
 
-        _aguix->copyToClipboard( s );
+        _aguix->copyToClipboard( s, AGUIX::PRIMARY_BUFFER );
     }
 }
 
@@ -1362,3 +1406,91 @@ void TextView::handleDoubleClick( int mx, int my )
     copySelectionToClipboard();
     redraw();
 }
+
+int TextView::scrollView( int xdelta, int ydelta )
+{
+    int res = 0;
+
+    if ( xdelta != 0 && hbar ) {
+        int old_offset = hbar->getOffset();
+        hbar->setOffset( old_offset + xdelta );
+        if ( hbar->getOffset() != old_offset ) {
+            res |= 1;
+        }
+    }
+    if ( ydelta != 0 && vbar ) {
+        int old_offset = vbar->getOffset();
+        vbar->setOffset( old_offset + ydelta );
+        if ( vbar->getOffset() != old_offset ) {
+            res |= 2;
+        }
+    }
+
+    if ( res != 0 ) {
+        redraw();
+    }
+
+    return res;
+}
+
+void TextView::updateSelection( int mx, int my )
+{
+    int x, y, w, h;
+
+    getTextArea( x, y, w, h );
+
+    // allow hitting exactly w/h to allow selection of last char/line,
+    // but limit to that area to avoid selection invisible text
+    if ( mx > x + w ) mx = x + w;
+    if ( mx < x ) mx = x;
+    if ( my > y + h ) my = y + h;
+    if ( my < y ) my = y;
+
+    std::pair< int, int > cur = getTextPosForMousePos( mx, my );
+
+    if ( cur != m_button_press_unwrapped_line_pos ) {
+        int cur_sel = - 1, cur_off = -1;
+
+        getSelectionEnd( cur_sel, cur_off );
+
+        if ( cur_sel != cur.first || cur_off != cur.second ) {
+            if ( m_button_press_unwrapped_line_pos.first < cur.first ||
+                 ( m_button_press_unwrapped_line_pos.first == cur.first &&
+                   m_button_press_unwrapped_line_pos.second < cur.second ) ) {
+                setSelectionStart( m_button_press_unwrapped_line_pos.first,
+                                   m_button_press_unwrapped_line_pos.second );
+                setSelectionEnd( cur.first,
+                                 cur.second );
+            } else {
+                setSelectionStart( cur.first,
+                                   cur.second );
+                setSelectionEnd( m_button_press_unwrapped_line_pos.first,
+                                 m_button_press_unwrapped_line_pos.second );
+            }
+
+            redraw();
+        }
+    }
+}
+
+void TextView::getTextArea( int &x, int &y,
+                            int &w, int &h )
+{
+    int lines;
+    int bw;
+
+    bw = ( _display_focus == true ) ? 3 : 2;
+
+    x = y = bw;
+
+    x += getTextStartOffset();
+
+    getLinesWidth( lines, w );
+
+    if ( cont != NULL ) {
+        h = cont->getHeight( 0, 0 ) - 2;
+        if ( h < 0 ) h = 0;
+    } else {
+        h = 0;
+    }
+}
