@@ -1,6 +1,6 @@
 /* textview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2018 Ralf Hoffmann.
+ * Copyright (C) 2005-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -155,6 +155,8 @@ protected:
     bool m_show_frame;
 
     Time m_last_mouse_time;
+
+    bool m_selection_scroll_active = false;
   
   void boxRedraw();
   void createContainer();
@@ -189,6 +191,11 @@ protected:
     void copySelectionToClipboard();
 
     void handleDoubleClick( int mx, int my );
+
+    int scrollView( int xdelta, int ydelta );
+    void updateSelection( int mx, int my );
+    void getTextArea( int &x, int &y,
+                      int &w, int &h );
 };
 
 #endif
