@@ -72,7 +72,7 @@ size_t UTF8::getLenOfCharacter( const char *str )
 
   // optimization for 7-bit characters, in utf8 characters with
   // more than 1 byte start with a highbit char
-  if ( *str >= 0 ) return 1;
+  if ( (signed char)*str >= 0 ) return 1;
   
   mbstate_t mbstate;
   memset( &mbstate, 0, sizeof( mbstate ) );
