@@ -1,6 +1,6 @@
 /* util.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -116,6 +116,10 @@ namespace AGUIXUtils
     void rstrip( std::string &str, const std::string &strip_chars );
     void strip( std::string &str );
 
+    /* removes the character from the string. is utf8 safe */
+    std::string remove_char( const std::string &str,
+                             char ch );
+
     std::string timeToString( time_t t );
     bool parseStringToTime( const std::string &time_string,
                             time_t *return_time );
@@ -133,6 +137,13 @@ namespace AGUIXUtils
     int unescape_characters( const std::string &input,
                              std::string &output,
                              escape_type_t type );
+
+    // this function replaces the first occurance of %s with a
+    // correctly quoted string. This function does not take into
+    // accounted protected characters like \%s.
+    std::string replace_percent_s_quoted( const std::string &src,
+                                          const std::string &replacement,
+                                          std::string *return_suffix );
 }
 
 #define TIMEMEASURE_T struct timeval
