@@ -1,6 +1,6 @@
 /* commandmenuop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013,2017 Ralf Hoffmann.
+ * Copyright (C) 2013-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -59,7 +59,7 @@ const char *CommandMenuOp::getName()
     return name;
 }
 
-int CommandMenuOp::run( WPUContext *wpu, ActionMessage *msg )
+int CommandMenuOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     msg->getWorker()->openCommandMenu( m_show_recently_used );
 
@@ -125,6 +125,15 @@ int CommandMenuOp::configure()
                     if ( msg->button.button == okb ) endmode = 0;
                     else if ( msg->button.button == cb ) endmode = 1;
                     break;
+                case AG_KEYPRESSED:
+                    if ( win->isParent( msg->key.window, false ) == true ) {
+                        switch ( msg->key.key ) {
+                            case XK_Escape:
+                                endmode = 1;
+                                break;
+                        }
+                    }
+                    break;
             }
             aguix->ReplyMessage( msg );
         }
