@@ -1,6 +1,6 @@
 /* copycore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2021 Ralf Hoffmann.
+ * Copyright (C) 2013-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -644,7 +644,8 @@ CopyCore::nm_newname_t CopyCore::getNewName4File( const FileEntry *oldfe, const
 
 CopyCore::nm_copy_t
 CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, const char *destdir,
-                   std::string *effective_target_fullname )
+                   std::string *effective_target_fullname,
+                   bool skip_ok_test )
 {
     NM_CopyOp_Dir *cod1 = NULL;
     bool nameok,createdir;
@@ -670,7 +671,32 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
         cowin->newfile( fe->name, "" );
     }
 
-    if ( m_cancel == false ) {
+    if ( ! skip_ok_test && ! cod->ok ) {
+        CopyOpWin *cowin = m_copyorder->cowin;
+        if ( cowin ) {
+            cowin->stoptimer();
+            auto textstr = AGUIXUtils::formatStringToString( catalog.getLocale( 1456 ),
+                                                             fe->fullname );
+            std::string buttonstr = catalog.getLocale( 629 );
+            buttonstr += "|";
+            buttonstr += catalog.getLocale( 225 );
+            buttonstr += "|";
+            buttonstr += catalog.getLocale( 8 );
+            int erg = m_copyorder->cowin->request( catalog.getLocale( 347 ),
+                                                   textstr,
+                                                   buttonstr );
+            if ( erg == 2 ) {
+                m_cancel=true;
+            } else if ( erg == 1 ) {
+                skip = true;
+            }
+            cowin->conttimer();
+        } else {
+            skip = true;
+        }
+    }
+
+    if ( m_cancel == false && skip == false ) {
         e1=getNewName4Dir(fe,destdir,&newname,acceptrename);
         if((e1==NM_NEWNAME_OK)||(e1==NM_NEWNAME_USE)) {
             // build new name
@@ -760,7 +786,7 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
                         cod1=(NM_CopyOp_Dir*)cod->subdirs->getFirstElement(id1);
                         while(cod1!=NULL) {
                             nm_copy_t ce1;
-                            ce1=copydir(cod1->fileentry,cod1,false,destsubdir, NULL);
+                            ce1=copydir(cod1->fileentry,cod1,false,destsubdir, NULL, false);
                             if((ce1==NM_COPY_OK)||(ce1==NM_COPY_NEED_DELETE)) {
                                 // success
                                 cod->error_counter+=cod1->error_counter;
@@ -871,10 +897,27 @@ CopyCore::copydir( const FileEntry *fe, NM_CopyOp_Dir *cod, bool acceptrename, c
         cowin->dir_finished();
     }
     if(newname!=NULL) _freesafe(newname);
-    if(m_cancel==true) return NM_COPY_CANCEL;
-    else if(skip==true) {
+    if(m_cancel==true) {
+        std::string d = fe->fullname;
+        d += "/";
+        m_incomplete_entries.push_back( d );
+
+        return NM_COPY_CANCEL;
+    } else if(skip==true) {
         cod->error_counter++;
+
+        std::string d = fe->fullname;
+        d += "/";
+        m_incomplete_entries.push_back( d );
+
         return NM_COPY_SKIP;
+    } else {
+        // in case continue was selected
+        if ( ! skip_ok_test && ! cod->ok ) {
+            std::string d = fe->fullname;
+            d += "/";
+            m_incomplete_entries.push_back( d );
+        }
     }
     if(m_copyorder->move==true) {
         if((cod->error_counter==0)&&(failedmove==true)) {
@@ -907,6 +950,7 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
     mode_t modeCheck;
     bool useLinkDest;
     std::string text, button;
+    bool user_skip = false;
   
     if ( fe->isLink == true && fe->isCorrupt == false && m_copyorder->follow_symlinks ) {
         bytesToCopy = fe->dsize();
@@ -1269,6 +1313,9 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
             switch(e1) {
                 case NM_NEWNAME_CANCEL:
                     m_cancel=true;
+                case NM_NEWNAME_SKIP:
+                    skip = true;
+                    user_skip = true;
                 default:
                     skip=true;
                     break;
@@ -1287,8 +1334,17 @@ CopyCore::copyfile( const FileEntry *fe, bool acceptrename, const char *destdir,
         }
     }
     if(newname!=NULL) _freesafe(newname);
-    if(m_cancel==true) return NM_COPY_CANCEL;
-    else if(skip==true) return NM_COPY_SKIP;
+    if(m_cancel==true) {
+        m_incomplete_entries.push_back( fe->fullname );
+
+        return NM_COPY_CANCEL;
+    } else if(skip==true) {
+        if ( ! user_skip ) {
+            m_incomplete_entries.push_back( fe->fullname );
+        }
+
+        return NM_COPY_SKIP;
+    }
     if(m_copyorder->move==true) {
         if((opok==true)&&(failedmove==true)) {
             // remember: failedmove is true when OS function rename failed
@@ -1846,12 +1902,44 @@ int CopyCore::executeCopyThread()
         }
 
         if ( tcod != NULL ) {
-            nm_copy_t ce1;
+            nm_copy_t ce1 = NM_COPY_OK;
             std::string target_fullname;
             std::string destdir;
 
-            if ( prepare_destination_dir( cbe, destdir, false ) == 0 ) {
-                ce1 = copydir( &cbe.entry(), tcod, true, destdir.c_str(), &target_fullname );
+            if ( ! tcod->ok ) {
+                CopyOpWin *cowin = m_copyorder->cowin;
+                if ( cowin ) {
+                    cowin->stoptimer();
+                    auto textstr = AGUIXUtils::formatStringToString( catalog.getLocale( 1456 ),
+                                                                     cbe.entry().fullname );
+                    std::string buttonstr = catalog.getLocale( 629 );
+                    buttonstr += "|";
+                    buttonstr += catalog.getLocale( 225 );
+                    buttonstr += "|";
+                    buttonstr += catalog.getLocale( 8 );
+                    int erg = m_copyorder->cowin->request( catalog.getLocale( 347 ),
+                                                           textstr,
+                                                           buttonstr );
+                    if ( erg == 2 ) {
+                        m_cancel=true;
+                        ce1 = NM_COPY_CANCEL;
+                    } else if ( erg == 1 ) {
+                        ce1 = NM_COPY_SKIP;
+                    }
+
+                    cowin->conttimer();
+                } else {
+                    ce1 = NM_COPY_SKIP;
+                }
+
+                std::string d = cbe.entry().fullname;
+                d += "/";
+                m_incomplete_entries.push_back( d );
+            }
+
+            if ( ce1 == NM_COPY_OK &&
+                 prepare_destination_dir( cbe, destdir, false ) == 0 ) {
+                ce1 = copydir( &cbe.entry(), tcod, true, destdir.c_str(), &target_fullname, true );
                 if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
                     // success
                     Worker::pushCommandLog( m_copyorder->move ? catalog.getLocale( 1420 ) : catalog.getLocale( 1419 ),
@@ -1900,6 +1988,7 @@ int CopyCore::executeCopyThread()
 
                 prepare_destination_dir( cbe, destdir, true );
             } else {
+                m_incomplete_entries.push_back( cbe.entry().fullname );
                 if ( m_cancel ) {
                     ce1 = NM_COPY_CANCEL;
                 } else {
@@ -2081,3 +2170,8 @@ void CopyCore::setFinished()
 
     m_finished_cond.notify_all();
 }
+
+const std::vector< std::string > &CopyCore::incomplete_entries() const
+{
+    return m_incomplete_entries;
+}
