@@ -21,13 +21,13 @@
 
 #include "worker.h"
 #include "copyopwin.hh"
-#include <aguix/util.h>
-#include <aguix/lowlevelfunc.h>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/bevelbox.h>
-#include <aguix/solidbutton.h>
-#include <aguix/choosebutton.h>
+#include "aguix/util.h"
+#include "aguix/lowlevelfunc.h"
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/bevelbox.h"
+#include "aguix/solidbutton.h"
+#include "aguix/choosebutton.h"
 #include "worker_locale.h"
 #include "datei.h"
 #include "pers_kvp.hh"
