@@ -1,6 +1,6 @@
 /* deleteop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -65,7 +65,7 @@ DeleteOp::getName()
 }
 
 int
-DeleteOp::run( WPUContext *wpu, ActionMessage *msg )
+DeleteOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
@@ -191,6 +191,15 @@ int DeleteOp::configure()
       } else if(msg->type==AG_BUTTONCLICKED) {
         if(msg->button.button==okb) ende=1;
         else if(msg->button.button==cancelb) ende=-1;
+      } else if ( msg->type == AG_KEYPRESSED ) {
+          if ( win->isParent( msg->key.window, false ) == true ) {
+              switch ( msg->key.key ) {
+                  case XK_Escape:
+                      ende = -1;
+                      break;
+              }
+          }
+          break;
       }
       aguix->ReplyMessage(msg);
     }
