@@ -1,6 +1,6 @@
 /* dircompareop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017-2022 Ralf Hoffmann.
+ * Copyright (C) 2017-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -275,7 +275,7 @@ int DirCompareOp::key_compare( const compare_element &lhs,
         } else if ( lhs.entry->stat_size() > rhs.entry->stat_size() ) {
             return 1;
         } else {
-#ifdef HAVE_OPENSSL_SHA256
+#if defined(HAVE_OPENSSL_EVP_SHA256) || defined(HAVE_OPENSSL_SHA256)
             return memcmp( &lhs.chksum, &rhs.chksum, sizeof( lhs.chksum ) );
 #else
             return 0;
@@ -300,13 +300,33 @@ int DirCompareOp::calc_checksum( compare_element &element ) const
         return 1;
     }
 
-#ifdef HAVE_OPENSSL_SHA256
+#if defined(HAVE_OPENSSL_EVP_SHA256) || defined(HAVE_OPENSSL_SHA256)
+#if defined(HAVE_OPENSSL_EVP_SHA256)
+    EVP_MD_CTX *mdctx;
+    const EVP_MD *md;
+    md = EVP_sha256();
+
+    if ( ! md ) {
+        return 1;
+    }
+
+    mdctx = EVP_MD_CTX_new();
+    if ( ! mdctx ) {
+        return 1;
+    }
+
+    int res = EVP_DigestInit_ex( mdctx, md, NULL );
+#elif defined(HAVE_OPENSSL_SHA256)
     SHA256_CTX c;
 
     int res = SHA256_Init( &c );
+#endif
 
     if ( res != 1 ) {
         fprintf( stderr, "Failed to init checksum\n" );
+#if defined(HAVE_OPENSSL_EVP_SHA256)
+        EVP_MD_CTX_free( mdctx );
+#endif
         return 1;
     }
 
@@ -314,6 +334,9 @@ int DirCompareOp::calc_checksum( compare_element &element ) const
 
     if ( fh.open( element.entry->getFullname().c_str(),
                   "r" ) != 0 ) {
+#if defined(HAVE_OPENSSL_EVP_SHA256)
+        EVP_MD_CTX_free( mdctx );
+#endif
         return 1;
     }
 
@@ -349,8 +372,12 @@ int DirCompareOp::calc_checksum( compare_element &element ) const
             break;
         }
 
+#if defined(HAVE_OPENSSL_EVP_SHA256)
+        res = EVP_DigestUpdate( mdctx, buf, bytes_read );
+#elif defined(HAVE_OPENSSL_SHA256)
         res = SHA256_Update( &c,
                              buf, bytes_read );
+#endif
         if ( res != 1 ) {
             fprintf( stderr, "Failed to update checksum\n" );
         }
@@ -367,7 +394,12 @@ int DirCompareOp::calc_checksum( compare_element &element ) const
         }
     }
 
+#if defined(HAVE_OPENSSL_EVP_SHA256)
+    res = EVP_DigestFinal_ex(mdctx, &element.chksum[0], NULL);
+    EVP_MD_CTX_free( mdctx );
+#elif defined(HAVE_OPENSSL_SHA256)
     res = SHA256_Final( &element.chksum[0], &c );
+#endif
     if ( res != 1 ) {
         fprintf( stderr, "Failed to get checksum\n" );
     }
@@ -959,7 +991,7 @@ DirCompareOp::doConfigure()
 
     delete win;
 
-#ifndef HAVE_OPENSSL_SHA256
+#if !defined(HAVE_OPENSSL_EVP_SHA256) && !defined(HAVE_OPENSSL_SHA256)
     if ( m_compare_mode == COMPARE_CHECKSUM ) {
         Worker::getRequester()->request( catalog.getLocale( 124 ),
                                          catalog.getLocale( 1365 ),
