@@ -60,7 +60,7 @@ DMCacheEntryNWC::~DMCacheEntryNWC()
 
 void DMCacheEntryNWC::setDir( std::unique_ptr< NWC::Dir > dir )
 {
-    m_dir = dir.release();
+    m_dir.reset( dir.release() );
 
     setupEntries();
 
