@@ -22,7 +22,7 @@
 #include "exprfilter_parser.hh"
 #include "exprfilter_eval.hh"
 #include "exprfilter_evalatoms.hh"
-#include <aguix/util.h>
+#include "aguix/util.h"
 
 ExprToken ExprFilterParser::getCurrentToken() const
 {
