@@ -1,6 +1,6 @@
 /* externalvdirop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017-2018 Ralf Hoffmann.
+ * Copyright (C) 2017-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -130,7 +130,7 @@ int ExternalVDirOp::handleOutput( Worker *w,
 }
 
 int
-ExternalVDirOp::run( WPUContext *wpu, ActionMessage *msg )
+ExternalVDirOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     std::string res_str;
     int res = 0;
