@@ -21,7 +21,7 @@
 
 #include "filenameshrinker.hh"
 #include "datei.h"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 
 FileNameShrinker::FileNameShrinker()
 {
