@@ -1,6 +1,6 @@
 /* fileviewerbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2017 Ralf Hoffmann.
+ * Copyright (C) 2010-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -42,12 +42,14 @@
 FileViewerBG::FileViewerBG( Worker *worker ) : win( NULL ),
                                                m_wrap_mode( false ),
                                                m_showlinenumbers_mode( false ),
+                                               m_use_alt_font( false ),
                                                ts( NULL ),
                                                tv( NULL ),
                                                search_sg( NULL ),
                                                okb( NULL ),
                                                wcb( NULL ),
                                                slncb( NULL ),
+                                               alt_font_cb( NULL ),
                                                jumplineb( NULL ),
                                                readmoreb( NULL ),
                                                reloadb( NULL ),
@@ -118,8 +120,9 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     fnt->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
 
     it1 = filelist.begin();
-  
-    RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( wconfig->getFont( 4 ).c_str() ) ) );
+
+    const std::string fontname = wconfig->getFont( m_use_alt_font ? 6 : 4 );
+    RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( fontname.c_str() ) ) );
 
     if ( buildTextView( *it1, ac1, fnt, lencalc ) != 0 ) {
         delete win;
@@ -132,7 +135,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1->readLimits();
     ac1_1->readLimits();
 
-    AContainer *ac1_3 = ac1->add( new AContainer( win, 6, 1 ), 0, 3 );
+    AContainer *ac1_3 = ac1->add( new AContainer( win, 7, 1 ), 0, 3 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -158,16 +161,22 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
                                2, 0, cincwnr );
     snp_cb->setBubbleHelpText( catalog.getLocale( 1177 ) );
 
+    alt_font_cb = ac1_3->addWidget( new ChooseButton( aguix, 0, 0,
+                                                      m_use_alt_font, catalog.getLocale( 1454 ),
+                                                      LABEL_RIGHT, 0 ),
+                                    3, 0, cincwnr );
+    alt_font_cb->setBubbleHelpText( catalog.getLocale( 1455 ) );
+
     jumplineb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 716 ), 2 ),
-                                     3, 0, cfix );
+                                     4, 0, cfix );
     jumplineb->setBubbleHelpText( catalog.getLocale( 1142 ) );
 
     m_showintab_b = ac1_3->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1178 ), 2 ),
-                                      4, 0, cfix );
+                                      5, 0, cfix );
     m_showintab_b->setBubbleHelpText( catalog.getLocale( 1179 ) );
 
     okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 2 ),
-                               5, 0, cfix );
+                               6, 0, cfix );
     okb->setBubbleHelpText( catalog.getLocale( 1143 ) );
 
     AContainer *ac1_4 = ac1->add( new AContainer( win, 5, 1 ), 0, 2 );
@@ -274,6 +283,12 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                     ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
                 }
                 tv->textStorageChanged();
+            } else if ( msg.choose.button == alt_font_cb ) {
+                std::string fontname = wconfig->getFont( msg.choose.state ? 6 : 4 );
+                RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( fontname.c_str() ) ) );
+                ts->setAWidth( lencalc );
+                tv->setFont( fontname.c_str() );
+                tv->redraw();
             }
             break;
         case AG_BUTTONCLICKED:
@@ -376,6 +391,15 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                                 search_sg->setText( "" );
                                 search_sg->activate();
                             }
+                        } else {
+                            if ( msg.key.key == XK_f ) {
+                                alt_font_cb->setState( ! alt_font_cb->getState() );
+                                std::string fontname = wconfig->getFont( alt_font_cb->getState() ? 6 : 4 );
+                                RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( fontname.c_str() ) ) );
+                                ts->setAWidth( lencalc );
+                                tv->setFont( fontname.c_str() );
+                                tv->redraw();
+                            }
                         }
                         break;
                     case XK_n:
@@ -421,6 +445,7 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
         aguix->unregisterBGHandler( win );
         FileViewer::setGlobalLineWrap( tv->getLineWrap() );
         FileViewer::setGlobalShowLineNumbers( tv->getShowLineNumbers() );
+        FileViewer::setGlobalUseAltFont( alt_font_cb->getState() );
     }
 }
 
@@ -514,7 +539,10 @@ int FileViewerBG::buildTextView( const std::string &filename,
     ts_search.reset( new SearchTextStorage( *ts ) );
 
     tv->setDisplayFocus( true );
-    tv->setFont( wconfig->getFont( 4 ).c_str() );
+
+    const std::string fontname = wconfig->getFont( m_use_alt_font ? 6 : 4 );
+
+    tv->setFont( fontname.c_str() );
     ac1->add( tv, 0, 1, cmin );
     tv->create();
     if ( fnt != NULL ) fnt->setText( filename.c_str() );
@@ -598,6 +626,16 @@ bool FileViewerBG::getShowLineNumbers() const
     return m_showlinenumbers_mode;
 }
 
+void FileViewerBG::setUseAltFont( bool nv )
+{
+    m_use_alt_font = nv;
+}
+
+bool FileViewerBG::getUseAltFont() const
+{
+    return m_use_alt_font;
+}
+
 void FileViewerBG::restartSearchFromTop()
 {
     ts_search->setSearchStartLine( 0 );
