@@ -1,6 +1,6 @@
 /* import.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -359,7 +359,7 @@ void WConfig::setDefaultConfig()
   key->setKeySym(XK_F5,0);
   b1->setDoubleKeys( keylist );
   fp = std::make_shared< CopyOp >();
-  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestFlags(true);
+  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestParameters( true );
   nc.push_back(fp);
   b1->setComs(nc);
   fp.reset();
@@ -426,7 +426,7 @@ void WConfig::setDefaultConfig()
   b1->setDoubleKeys( keylist );
   fp = std::make_shared< CopyOp >();
   std::dynamic_pointer_cast< CopyOp >(fp)->setMove(true);
-  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestFlags(true);
+  std::dynamic_pointer_cast< CopyOp >(fp)->setRequestParameters( true );
   nc.push_back(fp);
   b1->setComs(nc);
   fp.reset();
@@ -444,7 +444,7 @@ void WConfig::setDefaultConfig()
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
   fp = std::make_shared< CreateSymlinkOp >();
-  std::dynamic_pointer_cast< CreateSymlinkOp >(fp)->setRequestFlags(true);
+  std::dynamic_pointer_cast< CreateSymlinkOp >(fp)->setRequestParameters( true );
   nc.push_back(fp);
   b1->setComs(nc);
   fp.reset();
@@ -546,7 +546,7 @@ void WConfig::setDefaultConfig()
   b1->setDoubleKeys( keylist );
   key->setType( WCDoubleShortkey::WCDS_NORMAL );
   fp = std::make_shared< ChModOp >();
-  std::dynamic_pointer_cast< ChModOp >(fp)->setRequestFlags(true);
+  std::dynamic_pointer_cast< ChModOp >(fp)->setRequestParameters( true );
   nc.push_back(fp);
   b1->setComs(nc);
   fp.reset();
