@@ -277,7 +277,7 @@ void InformationMode::showinfos()
     _freesafe(tstr);
     
     if(fe->filetype!=NULL) {
-        NWCFlagProducer fpr( NULL, fe );
+        auto fpr = std::make_shared< NWCFlagProducer >( nullptr, fe );
         FlagReplacer rpl( fpr );
         std::string filetype_str;
 
