@@ -198,7 +198,7 @@ void ListerMode::runCommandWithStrArgs( const std::string &command_str )
                 if ( i == 0 ) {
                     command = tstr1;
                 } else {
-                    string_args.push_back( new StringArg( tstr1 ) );
+                    string_args.push_back( RefCount< ArgClass >( new StringArg( tstr1 ) ) );
                 }
 
                 _freesafe( tstr1 );
