@@ -1,6 +1,6 @@
 /* makedirop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,14 +33,11 @@ public:
   MakeDirOp( const MakeDirOp &other );
   MakeDirOp &operator=( const MakeDirOp &other );
 
-  virtual MakeDirOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
-#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
-  using FunctionProto::run;
-#endif
-  int run( WPUContext *wpu, ActionMessage* );
-  virtual const char *getDescription();
+  MakeDirOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
+  const char *getDescription() override;
 protected:
   static const char *name;
   // Infos to save
