@@ -183,7 +183,7 @@ void NMExtList::createExtList( ListerMode *lm, ActionMessage *msg, bool rec )
     case ActionMessage::AM_MODE_SPECIFIC_ENTRIES:
         {
             RefCount< NWC::VirtualDir > vd = msg->getEntriesToConsider();
-            if ( vd.getVal() != NULL ) {
+            if ( vd.get() != NULL ) {
                 ExtListDirWalk w( lm, splist );
                 vd->walk( w );
             }
