@@ -584,6 +584,12 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
 
   lv = (FieldListView*)ac1_1->add( new FieldListView( aguix, 0, 0, 100, 7 * aguix->getCharHeight(), 0 ), 0, 0, cmin );
 
+  lv->setNrOfFields( 2 );
+  lv->setGlobalFieldSpace( 5 );
+  lv->setFieldText( 0, catalog.getLocale( 1443 ) );
+  lv->setFieldText( 1, catalog.getLocale( 1444 ) );
+  lv->setShowHeader( true );
+  lv->setConsiderHeaderWidthForDynamicWidth( true );
   lv->setHBarState( 2 );
   lv->setVBarState( 2 );
   lv->setDisplayFocus( true );
@@ -598,27 +604,48 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
   bool matched = false;
 
   std::list< std::string > cur_history = m_history->getList();
-  for ( std::list< std::string >::const_iterator it1 = cur_history.begin();
-        it1 != cur_history.end();
-        it1++ ) {
-      row = lv->insertRow( 0 );
-      lv->setText( row, 0, *it1 );
-      lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
 
-      if ( m_auto_filter && ! matched && ! fullname.empty() && *it1 != "*" ) {
+  if ( fullname.empty() ) {
+      for ( auto &p : cur_history ) {
+          row = lv->insertRow( 0 );
+          lv->setText( row, 0, p );
+          lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+      }
+  } else {
+      for ( auto &p : cur_history ) {
           StringMatcherFNMatch matcher;
 
-          matcher.setMatchString( *it1 );
+          matcher.setMatchString( p );
 
-          if ( matcher.match( fullname ) ) {
-              default_value = *it1;
+          if ( ! matcher.match( fullname ) ) continue;
+
+          row = lv->insertRow( 0 );
+          lv->setText( row, 0, p );
+          lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+          
+          if ( m_auto_filter && ! matched && p != "*" ) {
+              default_value = p;
 
               // the latest entry is at the beginning, so stop matching
               // after the first hit
               matched = true;
           }
       }
+
+      for ( auto &p : cur_history ) {
+          StringMatcherFNMatch matcher;
+
+          matcher.setMatchString( p );
+
+          if ( matcher.match( fullname ) ) continue;
+
+          row = lv->insertRow( 0 );
+          lv->setText( row, 1, p );
+          lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
+          //lv->setStrikeOut( row, 0, true );
+      }
   }
+  
   lv->showRow( cur_history.size() - 1 );
   lv->redraw();
 
@@ -630,6 +657,8 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
 
           default_value = "*";
           default_value += suffix;
+      } else {
+          default_value = "*";
       }
   }
 
@@ -722,7 +751,11 @@ bool FilterSelectOp::requestfilter( const std::string &fullname )
         else lvstill = false;
         lastrow = row;
         if ( lv->isValidRow( row ) == true ) {
-            sg->setText( lv->getText( row, 0 ).c_str() );
+            if ( lv->getText( row, 0 ).empty() ) {
+                sg->setText( lv->getText( row, 1 ).c_str() );
+            } else {
+                sg->setText( lv->getText( row, 0 ).c_str() );
+            }
         }
       }
       aguix->ReplyMessage(msg);
@@ -914,7 +947,7 @@ int Path2OSideOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                 if(lm1!=NULL) {
                     std::list< RefCount< ArgClass > > args;
 
-                    args.push_back( new StringArg( dir ) );
+                    args.push_back( RefCount< ArgClass >( new StringArg( dir ) ) );
                     lm1->runCommand( "enter_dir", args );
                 }
             }
