@@ -136,7 +136,8 @@ namespace NWC {
             std::string parent_dirname = fse.getDirname();
 
             if ( parent_dirname != "" &&
-                 parent_dirname != "." ) {
+                 parent_dirname != "." &&
+                 parent_dirname != "/" ) {
                 int res = make_dirs( parent_dirname );
 
                 if ( res != 0 ) {
