@@ -28,7 +28,7 @@
 #include "configtokens.h"
 #include "configheader.h"
 #include "configparser.hh"
-#include <aguix/util.h>
+#include "aguix/util.h"
 #include "filelock.hh"
 
 PrefixDB::PrefixDB( const std::string &filename ) : m_next_aging( 0 ),
