@@ -1,6 +1,6 @@
 /* scriptop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2014 Ralf Hoffmann.
+ * Copyright (C) 2002-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -50,16 +50,13 @@ public:
   ScriptOp( const ScriptOp &other );
   ScriptOp &operator=( const ScriptOp &other );
 
-  virtual ScriptOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
-#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
-  using FunctionProto::run;
-#endif
-  virtual int run(WPUContext*,ActionMessage*);
-  virtual const char *getDescription();
-  virtual int configure();
-  virtual bool save(Datei*);
+  ScriptOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
+  const char *getDescription() override;
+  int configure() override;
+  bool save(Datei*) override;
 
   bool isLabel( const char *str );
   typedef enum { SCRIPT_NOP = 0,
