@@ -112,7 +112,7 @@ int SearchOp::prepareWindow( ActionMessage *msg )
         }
     }
 
-    RefCount< SearchOpBG > sbg = new SearchOpBG( msg->getWorker() );
+    RefCount< SearchOpBG > sbg( new SearchOpBG( msg->getWorker() ) );
 
     sbg->setInitialVDir( std::move( start_vdir ) );
     sbg->setInitialStartDir( _initial_start_dir );
