@@ -211,7 +211,7 @@ void SearchOpBG::enterResult( const std::string &fullname )
         if ( lm1 != NULL ) {
             std::list< RefCount< ArgClass > > args;
 
-            args.push_back( new StringArg( fullname ) );
+            args.push_back( RefCount< ArgClass >( new StringArg( fullname ) ) );
             lm1->runCommand( "enter_dir", args );
         }
     }
@@ -840,7 +840,7 @@ SearchOpBG::SearchOpBG( Worker *worker ) :
     m_stored_result_last_changed( 0 ),
     m_timeout_set( false )
 {
-    m_timeout_cb = new SearchOpBGTimeoutCB( this );
+    m_timeout_cb.reset( new SearchOpBGTimeoutCB( this ) );
 }
 
 SearchOpBG::~SearchOpBG()
