@@ -1,6 +1,6 @@
 /* setsortmodeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -64,7 +64,7 @@ const char *SetSortmodeOp::getName()
   return name;
 }
 
-int SetSortmodeOp::run( WPUContext *wpu, ActionMessage *msg )
+int SetSortmodeOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
@@ -240,6 +240,15 @@ int SetSortmodeOp::configure()
           if(msg->button.button==okb) endmode=0;
           else if(msg->button.button==cb) endmode=1;
           break;
+        case AG_KEYPRESSED:
+            if ( win->isParent( msg->key.window, false ) == true ) {
+                switch ( msg->key.key ) {
+                    case XK_Escape:
+                        endmode = 1;
+                        break;
+                }
+            }
+            break;
       }
       aguix->ReplyMessage(msg);
     }
@@ -334,7 +343,30 @@ void SetSortmodeOp::setSortFlag( int f )
   }
 }
 
-/**********************
- Ende SetSortmodeOp
-***********************/
+std::string SetSortmodeOp::getStringRepresentation()
+{
+    std::string res = getDescription();
 
+    res += " (";
+
+    if ( ( mode & 0xff ) == SORT_SIZE ) res += catalog.getLocale( 161 );
+    else if ( ( mode & 0xff ) == SORT_ACCTIME ) res += catalog.getLocale( 162 );
+    else if ( ( mode & 0xff ) == SORT_MODTIME ) res += catalog.getLocale( 163 );
+    else if ( ( mode & 0xff ) == SORT_CHGTIME ) res += catalog.getLocale( 164 );
+    else if ( ( mode & 0xff ) == SORT_TYPE ) res += catalog.getLocale( 432 );
+    else if ( ( mode & 0xff ) == SORT_OWNER ) res += catalog.getLocale( 433 );
+    else if ( ( mode & 0xff ) == SORT_INODE ) res += catalog.getLocale( 552 );
+    else if ( ( mode & 0xff ) == SORT_NLINK ) res += catalog.getLocale( 553 );
+    else if ( ( mode & 0xff ) == SORT_PERMISSION ) res += catalog.getLocale( 907 );
+    else if ( ( mode & 0xff ) == SORT_EXTENSION ) res += catalog.getLocale( 1240 );
+    else res += catalog.getLocale( 160 );
+
+    if ( ( mode & SORT_REVERSE ) == SORT_REVERSE ) {
+        res += ", ";
+        res += catalog.getLocale( 1374 );
+    }
+
+    res += ")";
+
+    return res;
+}
