@@ -20,7 +20,7 @@
  */
 
 #include "simplelist.hh"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 
 List::List()
 {
