@@ -1,6 +1,6 @@
 /* stringmatcher_fnmatch.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007,2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2007-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,7 @@
 #include "stringmatcher_fnmatch.hh"
 #include "aguix/lowlevelfunc.h"
 #include "aguix/utf8.hh"
+#include "aguix/util.h"
 #include <cctype>
 #include <algorithm>
 #include <functional>
@@ -85,24 +86,9 @@ bool StringMatcherFNMatch::getMatchCaseSensitive() const
     return _match_case_sensitive;
 }
 
-template <class T>
-struct my_tolower : public std::unary_function<T,T> 
-{
-    T operator() (const T& c) const 
-    {
-        return std::tolower( c );
-    }
-};
-
-
 void StringMatcherFNMatch::createLoweredCase()
 {
-    _match_string_lowercase = _match_string;
-
-    std::transform( _match_string_lowercase.begin(),
-                    _match_string_lowercase.end(),
-                    _match_string_lowercase.begin(),
-                    my_tolower<char>() );
+    _match_string_lowercase = AGUIXUtils::tolower( _match_string );
 }
 
 std::string StringMatcherFNMatch::convertMatchStringToFlexibleMatch( const std::string &str )
