@@ -1,6 +1,6 @@
 /* textstoragefile.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2017 Ralf Hoffmann.
+ * Copyright (C) 2005-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -92,6 +92,12 @@ AWidth &TextStorageFile::getAWidth()
     return m_tss.getAWidth();
 }
 
+void TextStorageFile::setAWidth( const RefCount<AWidth> &lencalc )
+{
+    m_lencalc = lencalc;
+    m_tss.setAWidth( lencalc );
+}
+
 int TextStorageFile::findLineNr( std::pair<int,int> real_line ) const
 {
     return m_tss.findLineNr( real_line );
