@@ -83,8 +83,8 @@ void TextViewMode::messageHandler( AGMessage *msg )
 
 void TextViewMode::on()
 {
-    m_lencalc = new AFontWidth( aguix, aguix->getFont( wconfig->getFont( 4 ).c_str() ) );
-    m_ts = new TextStorageFile( "", m_lencalc, TVM_DEFAULT_SIZE, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
+    m_lencalc.reset( new AFontWidth( aguix, aguix->getFont( wconfig->getFont( 4 ).c_str() ) ) );
+    m_ts.reset( new TextStorageFile( "", m_lencalc, TVM_DEFAULT_SIZE, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE ) );
 
     m_cont = new AContainer( parentawindow, 1, 2 );
     m_cont->setBorderWidth( 0 );
