@@ -1,6 +1,6 @@
 /* virtualdirmode_copy.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2022 Ralf Hoffmann.
+ * Copyright (C) 2013-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,9 @@
 
 #include "virtualdirmode.hh"
 #include "aguix/fieldlistviewdnd.h"
+#include "aguix/textstorage.h"
+#include "aguix/textview.h"
+#include "aguix/button.h"
 #include "worker_locale.h"
 #include "worker.h"
 #include "nwcentryselectionstate.hh"
@@ -399,6 +402,92 @@ void VirtualDirMode::handle_bg_copy_ops( bool skip_message_handling )
     }
 }
 
+void VirtualDirMode::showListOfIncompleteEntries( const std::vector< std::string > &entries )
+{
+    auto win = std::unique_ptr<AWindow>( new AWindow( aguix,
+                                                      0, 0,
+                                                      500, 400,
+                                                      catalog.getLocale( 1457 ),
+                                                      AWindow::AWINDOW_DIALOG  ) );
+    win->setTransientForAWindow( aguix->getTransientWindow() );
+    win->create();
+
+    AContainer *cont0 = win->setContainer( new AContainer( win.get(), 1, 3 ), true );
+    cont0->setMaxSpace( 5 );
+
+    win->addMultiLineText( catalog.getLocale( 1458 ), *cont0, 0, 0, NULL, NULL );
+
+    auto lv = dynamic_cast<FieldListView*>( cont0->add( new FieldListView( aguix, 0, 0, 
+                                                                           500, 200, 0 ),
+                                                        0, 1, AContainer::CO_MIN ) );
+    lv->setNrOfFields( 1 );
+    lv->setHBarState( 2 );
+    lv->setVBarState( 2 );
+    lv->setDefaultColorMode( FieldListView::PRECOLOR_NOTSELORACT);
+
+    for ( const auto &e : entries ) {
+        int row = lv->addRow();
+        lv->setText( row, 0, e );
+    }
+
+    AContainer *cont2 = cont0->add( new AContainer( win.get(), 3, 1 ), 0, 2 );
+    cont2->setBorderWidth( 0 );
+    cont2->setMinSpace( 0 );
+    cont2->setMaxSpace( -1 );
+
+    auto closeb = dynamic_cast<Button*>( cont2->add( new Button( aguix, 0, 0,
+                                                                 catalog.getLocale( 633 ),
+                                                                 0 ),
+                                                     1, 0, AContainer::CO_FIX ) );
+   
+    win->setDoTabCycling( true );
+    win->contMaximize( true );
+    win->centerScreen();
+    win->show();
+
+    closeb->takeFocus();
+
+    AGMessage *msg;
+    int endmode = -1;
+
+    for(; endmode == -1; ) {
+        msg = aguix->WaitMessage( win.get() );
+        if ( msg != NULL ) {
+            switch ( msg->type ) {
+                case AG_CLOSEWINDOW:
+                    if ( msg->closewindow.window == win->getWindow() ) {
+                        endmode = 2;
+                    }
+                    break;
+                case AG_BUTTONCLICKED:
+                    if ( msg->button.button == closeb ) {
+                        endmode = 0;
+                    }
+                    break;
+                case AG_KEYPRESSED:
+                    if ( win->isParent( msg->key.window, false ) == true ) {
+                        switch ( msg->key.key ) {
+                            case XK_KP_Enter:
+                            case XK_Return:
+                                if ( closeb->getHasFocus() == true ) {
+                                    endmode = 0;
+                                }
+                                break;
+                            case XK_Escape:
+                                endmode = 2;
+                                break;
+                            case XK_F1:
+                                endmode = 0;
+                                break;
+                        }
+                    }
+                    break;
+            }
+            aguix->ReplyMessage( msg );
+        }
+    }
+}
+
 void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
 {
     if ( m_lv ) {
@@ -459,6 +548,10 @@ void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
                                      } );
     }
 
+    if ( ! cc->getCancel() && ! cc->incomplete_entries().empty() ) {
+        showListOfIncompleteEntries( cc->incomplete_entries() );
+    }
+    
     if ( co->cowin != NULL ) {
         if ( co->cowin->getKeepWindow() &&
              ! cc->getCancel() ) {
