@@ -1,6 +1,6 @@
 /* volumemanagerui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2014 Ralf Hoffmann.
+ * Copyright (C) 2009-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -372,15 +372,6 @@ static bool volumeInList( const HWVolume &vol,
     return false;
 }
 
-struct hwvolume_cmpf : public std::binary_function<HWVolume, HWVolume, bool>
-{
-    bool operator()( const HWVolume &lhs,
-                     const HWVolume &rhs ) const
-    {
-        return lhs.getDevice() < rhs.getDevice();
-    }
-};
-
 void VolumeManagerUI::updateLV()
 {
     std::list<HWVolume> l = m_hwman.getVolumes();
@@ -393,7 +384,9 @@ void VolumeManagerUI::updateLV()
         cur_smp = m_lv->getText( cur_row, 0 );
     }
     
-    l.sort( hwvolume_cmpf() );
+    l.sort( []( auto &lhs, auto &rhs ) {
+                return lhs.getDevice() < rhs.getDevice();
+            });
 
     m_lv->setSize( 0 );
     m_row_to_volume.clear();
@@ -638,7 +631,9 @@ void VolumeManagerUI::buildEjectMenu( const menu_command_t &menu_command )
 
     m_menu_command = menu_command;
     std::list< HWVolume > l = m_hwman.getEjectableDevices();
-    l.sort( hwvolume_cmpf() );
+    l.sort( []( auto &lhs, auto &rhs ) {
+                return lhs.getDevice() < rhs.getDevice();
+            });
 
     m_ejectable_devices.clear();
     for ( std::list< HWVolume >::iterator it1 = l.begin();
