@@ -1,6 +1,6 @@
 /* wchotkey.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2006-2020 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,21 +22,18 @@
 #include "wchotkey.hh"
 #include "wcdoubleshortkey.hh"
 #include "datei.h"
-#include <aguix/util.h>
+#include "aguix/util.h"
 #include "functionproto.h"
 #include "simplelist.hh"
  
 WCHotkey::WCHotkey()
 {
   name=dupstring("");
-  com=new List();
 }
 
 WCHotkey::~WCHotkey()
 {
   if(name!=NULL) _freesafe(name);
-  freecoms(com);
-  delete com;
 }
 
 WCHotkey *WCHotkey::duplicate() const
@@ -63,28 +60,17 @@ char *WCHotkey::getName()
   return name;
 }
 
-List *WCHotkey::getComs()
+command_list_t WCHotkey::getComs()
 {
   return com;
 }
 
-void WCHotkey::setComs(List *ncom)
+void WCHotkey::setComs( const command_list_t &ncom)
 {
-  freecoms(com);
-  FunctionProto *fp;
-  int id=ncom->initEnum();
-  fp=(FunctionProto*)ncom->getFirstElement(id);
-  while(fp!=NULL) {
-    com->addElement(fp->duplicate());
-    fp=(FunctionProto*)ncom->getNextElement(id);
-  }
-  com->closeEnum(id);  
-}
-
-void WCHotkey::addCom( const FunctionProto *fp )
-{
-  if ( fp == NULL ) return;
-  com->addElement( fp->duplicate() );
+    com.clear();
+    for ( auto &fp : ncom ) {
+        com.push_back( std::shared_ptr< FunctionProto >( fp->duplicate() ) );
+    }
 }
 
 bool WCHotkey::save(Datei *fh) const
@@ -107,13 +93,9 @@ bool WCHotkey::save(Datei *fh) const
   fh->configCloseSection(); //shortkeys
 
   fh->configOpenSection( "commands" );
-  id = com->initEnum();
-  FunctionProto *f1 = (FunctionProto*)com->getFirstElement( id );
-  while ( f1 != NULL ) {
-    FunctionProto::presave( fh, f1 );
-    f1 = (FunctionProto*)com->getNextElement( id );
+  for ( auto &f1 : com ) {
+      FunctionProto::presave( fh, f1.get() );
   }
-  com->closeEnum( id );
   fh->configCloseSection(); //commands
   return true;
 }
