@@ -126,7 +126,7 @@ int DCDPanel::saveValues()
   return 0;
 }
 
-void DCDPanel::run( Widget *elem, AGMessage &msg )
+void DCDPanel::run( Widget *elem, const AGMessage &msg )
 {
   char *tstr,*buttonstr,*tstr2;
   const char *textstr;
