@@ -94,7 +94,7 @@ int TermConfPanel::saveValues()
   return 0;
 }
 
-void TermConfPanel::run( Widget *elem, AGMessage &msg )
+void TermConfPanel::run( Widget *elem, const AGMessage &msg )
 {
   if ( msg.type == AG_STRINGGADGET_CONTENTCHANGE ) {
     if ( msg.stringgadget.sg == sg ) {
