@@ -104,7 +104,7 @@ extern "C" {
 #endif
 
 #define OUTPUT_BIN "xmessage -file %s"
-#define TERMINAL_BIN "xterm -e %s"
+#define TERMINAL_BIN "xterm -e /bin/sh %s"
 
 #ifndef LINUX
   #ifndef ARG_MAX
